@@ -1,27 +1,14 @@
 /*
- *  $Id: example.cpp,v 1.1 2000/11/14 05:42:03 sbooth Exp $
+ * $Id: example.cpp,v 1.3 2001/09/03 22:11:55 sbooth Exp $ 
  *
- *  Copyright (C) 1996, 1997, 1998, 1999, 2000 Stephen F. Booth
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Skeleton of a CGI application written using the GNU cgicc library
  */
 
 #include <exception>
 #include <iostream>
 
 #include "cgicc/Cgicc.h"
+#include "cgicc/HTTPHeaders.h"
 #include "cgicc/HTMLClasses.h"
 
 // To use the debug logging feature, the variable gLogFile MUST be
@@ -47,7 +34,7 @@ main(int argc,
     
     // Output the HTTP headers for an HTML document, and the HTML 4.0 DTD info
     cout << HTTPHTMLHeader() << HTMLDoctype(HTMLDoctype::eStrict) << endl;
-    cout << html().set("lang", "EN").set("dir", "LTR") << endl;
+    cout << html().set("lang", "en").set("dir", "ltr") << endl;
 
     // Set up the page's header and title.
     cout << head() << endl;
